@@ -5,13 +5,67 @@ This chart provides a library to bootstrap a Plone deployment on a Kubernetes cl
 
 It provides
 
-* backend (with `plone.volto` or Classic-UI)
-* frontend (Plone-Volto, a ReactJS based user interface)
-* varnish (optional)
+* Backend (for API with `plone.volto` or as Classic-UI)
+* Frontend (Plone-Volto, a ReactJS based user interface)
+* Varnish using kube-httpcache. It includes a way to invalidate varnish cluster (optional)
+
+## Installation
+
+### Typescript
+
+To use this library, create a new CDK8S project (or use an existing one)
+
+```bash
+cdk8s init typescript-app
+```
+
+Then add the following dependency to `package.json`:
+
+```json
+{
+  "dependencies": {
+    "@bluedynamics/cdk8s-plone": "*"
+  }
+}
+```
+
+Run `npm install` to install the new dependency.
+
+### Python
+
+Todo: Document in details how to install.
+
+```bash
+cdk8s init python-app
+```
+
+Python package name is [cdk8s-plone](https://pypi.org/project/cdk8s-plone/).
 
 ## Usage
 
-For now have a look at the [example project](https://github.com/bluedynamics/cdk8s-plone-example)..
+With `cdk8s-cli` installed, create a new project:
+
+```bash
+cdk8s sythn
+```
+
+Add the following code to your `main.ts`:
+
+```python
+...
+import { Plone } from '@bluedynamics/cdk8s-plone';
+...
+    super(scope, id, props);
+
+    // define resources here
+    new Plone(this, 'Plone', {});
+...
+```
+
+Run `npm run build ` to generate the Kubernetes manifests.
+The manifests are stored in the `dist` directory.
+
+For more have a look at the [example project](https://github.com/bluedynamics/cdk8s-plone-example).
 
 ## Development
 
@@ -27,41 +81,41 @@ Then run the following command to run the test:
 npx projen test
 ```
 
-### WIP Checklist:
+### Feature Wishlist:
 
 Each step need to be implemented with tests!
 
+* [x] Support Variants for ClassicUI or Volto
 * [ ] Start Backend
 
   * [x] deployment
   * [x] service
   * [x] pdb
-  * [ ] init container running plone-site-create
+  * [ ] init container running `plone-site-create`
   * [x] lifecycle checks (readiness, liveness)
   * [x] generic way to inject sidecars
+  * [ ] metrics sidecar
 * [ ] Start Frontend
 
   * [x] deployment
   * [x] service
   * [x] pdb
-  * [ ] lifecycle checks (readiness, liveness)
-  * [ ] depend on ready/live backend (needed?)
+  * [x] lifecycle checks (readiness, liveness)
   * [x] generic way to inject sidecars
-* [ ] Start Varnish
+  * [ ] metrics sidecar
+* [x] Start Varnish (using `kube-httpcache`) optional in separate chart
 
-  * [ ] deployment
+  * [x] provide a default VCL for Volto with routing to backend and frontend
+  * [ ] provide a default VCL for ClassicUI
+* [ ] Configure Ingress, optional in separate chart
 
-    * [ ] do not depend on backend/front end to be  up, but configure to deliver from cache if possible.
-  * [ ] service
-  * [ ] pdb
-  * [ ] lifecycle checks (readiness, liveness)
-  * [ ] generic way to inject sidecars
-  * find a way to purge caches. based on kitconcept varnish purger? needs
-* [ ] Other Languages
+  * [ ] Traefik
+  * [ ] Konq
+* [ ] Release packages for other Languages
 
-  * [x] Check Python distribution
-  * [ ] Check Java distribution
-  * [ ] Check Go distribution
+  * [x] Python
+  * [ ] Golang
+  * [ ] Java
 '''
 from pkgutil import extend_path
 __path__ = extend_path(__path__, __name__)
@@ -98,6 +152,7 @@ class Plone(
         frontend: typing.Optional[typing.Union["PloneBaseOptions", typing.Dict[builtins.str, typing.Any]]] = None,
         image_pull_secrets: typing.Optional[typing.Sequence[builtins.str]] = None,
         site_id: typing.Optional[builtins.str] = None,
+        variant: typing.Optional["PloneVariant"] = None,
         version: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -107,6 +162,7 @@ class Plone(
         :param frontend: 
         :param image_pull_secrets: 
         :param site_id: 
+        :param variant: 
         :param version: 
         '''
         if __debug__:
@@ -118,6 +174,7 @@ class Plone(
             frontend=frontend,
             image_pull_secrets=image_pull_secrets,
             site_id=site_id,
+            variant=variant,
             version=version,
         )
 
@@ -128,10 +185,20 @@ class Plone(
     def backend_service_name(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "backendServiceName"))
 
+    @builtins.property
+    @jsii.member(jsii_name="siteId")
+    def site_id(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "siteId"))
+
+    @builtins.property
+    @jsii.member(jsii_name="variant")
+    def variant(self) -> "PloneVariant":
+        return typing.cast("PloneVariant", jsii.get(self, "variant"))
+
     @builtins.property
     @jsii.member(jsii_name="frontendServiceName")
-    def frontend_service_name(self) -> builtins.str:
-        return typing.cast(builtins.str, jsii.get(self, "frontendServiceName"))
+    def frontend_service_name(self) -> typing.Optional[builtins.str]:
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "frontendServiceName"))
 
 
 @jsii.data_type(
@@ -385,6 +452,194 @@ class PloneBaseOptions:
         )
 
 
+class PloneHttpcache(
+    _constructs_77d1e7e8.Construct,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@bluedynamics/cdk8s-plone.PloneHttpcache",
+):
+    def __init__(
+        self,
+        scope: _constructs_77d1e7e8.Construct,
+        id: builtins.str,
+        *,
+        plone: Plone,
+        existing_secret: typing.Optional[builtins.str] = None,
+        limit_cpu: typing.Optional[builtins.str] = None,
+        limit_memory: typing.Optional[builtins.str] = None,
+        request_cpu: typing.Optional[builtins.str] = None,
+        request_memory: typing.Optional[builtins.str] = None,
+        varnish_vcl: typing.Optional[builtins.str] = None,
+        varnish_vcl_file: typing.Optional[builtins.str] = None,
+    ) -> None:
+        '''
+        :param scope: -
+        :param id: -
+        :param plone: plone chart. Default: - none
+        :param existing_secret: existingSecret - Read admin credentials from user provided secret. Default: - undefined
+        :param limit_cpu: 
+        :param limit_memory: 
+        :param request_cpu: 
+        :param request_memory: 
+        :param varnish_vcl: varnishVcl. Default: - file in config folder
+        :param varnish_vcl_file: varnishVclFile. Default: - undefined
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__f7f85fe682616b18a7851bccc28d7021f541060ebc9eba02965066fd28589e69)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+        options = PloneHttpcacheOptions(
+            plone=plone,
+            existing_secret=existing_secret,
+            limit_cpu=limit_cpu,
+            limit_memory=limit_memory,
+            request_cpu=request_cpu,
+            request_memory=request_memory,
+            varnish_vcl=varnish_vcl,
+            varnish_vcl_file=varnish_vcl_file,
+        )
+
+        jsii.create(self.__class__, self, [scope, id, options])
+
+    @builtins.property
+    @jsii.member(jsii_name="httpcacheServiceName")
+    def httpcache_service_name(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "httpcacheServiceName"))
+
+
+@jsii.data_type(
+    jsii_type="@bluedynamics/cdk8s-plone.PloneHttpcacheOptions",
+    jsii_struct_bases=[],
+    name_mapping={
+        "plone": "plone",
+        "existing_secret": "existingSecret",
+        "limit_cpu": "limitCpu",
+        "limit_memory": "limitMemory",
+        "request_cpu": "requestCpu",
+        "request_memory": "requestMemory",
+        "varnish_vcl": "varnishVcl",
+        "varnish_vcl_file": "varnishVclFile",
+    },
+)
+class PloneHttpcacheOptions:
+    def __init__(
+        self,
+        *,
+        plone: Plone,
+        existing_secret: typing.Optional[builtins.str] = None,
+        limit_cpu: typing.Optional[builtins.str] = None,
+        limit_memory: typing.Optional[builtins.str] = None,
+        request_cpu: typing.Optional[builtins.str] = None,
+        request_memory: typing.Optional[builtins.str] = None,
+        varnish_vcl: typing.Optional[builtins.str] = None,
+        varnish_vcl_file: typing.Optional[builtins.str] = None,
+    ) -> None:
+        '''
+        :param plone: plone chart. Default: - none
+        :param existing_secret: existingSecret - Read admin credentials from user provided secret. Default: - undefined
+        :param limit_cpu: 
+        :param limit_memory: 
+        :param request_cpu: 
+        :param request_memory: 
+        :param varnish_vcl: varnishVcl. Default: - file in config folder
+        :param varnish_vcl_file: varnishVclFile. Default: - undefined
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__0f974bf721e34d8993ba90020605bc5e09424793236af8b8c5a9bb9a63f1974a)
+            check_type(argname="argument plone", value=plone, expected_type=type_hints["plone"])
+            check_type(argname="argument existing_secret", value=existing_secret, expected_type=type_hints["existing_secret"])
+            check_type(argname="argument limit_cpu", value=limit_cpu, expected_type=type_hints["limit_cpu"])
+            check_type(argname="argument limit_memory", value=limit_memory, expected_type=type_hints["limit_memory"])
+            check_type(argname="argument request_cpu", value=request_cpu, expected_type=type_hints["request_cpu"])
+            check_type(argname="argument request_memory", value=request_memory, expected_type=type_hints["request_memory"])
+            check_type(argname="argument varnish_vcl", value=varnish_vcl, expected_type=type_hints["varnish_vcl"])
+            check_type(argname="argument varnish_vcl_file", value=varnish_vcl_file, expected_type=type_hints["varnish_vcl_file"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
+            "plone": plone,
+        }
+        if existing_secret is not None:
+            self._values["existing_secret"] = existing_secret
+        if limit_cpu is not None:
+            self._values["limit_cpu"] = limit_cpu
+        if limit_memory is not None:
+            self._values["limit_memory"] = limit_memory
+        if request_cpu is not None:
+            self._values["request_cpu"] = request_cpu
+        if request_memory is not None:
+            self._values["request_memory"] = request_memory
+        if varnish_vcl is not None:
+            self._values["varnish_vcl"] = varnish_vcl
+        if varnish_vcl_file is not None:
+            self._values["varnish_vcl_file"] = varnish_vcl_file
+
+    @builtins.property
+    def plone(self) -> Plone:
+        '''plone chart.
+
+        :default: - none
+        '''
+        result = self._values.get("plone")
+        assert result is not None, "Required property 'plone' is missing"
+        return typing.cast(Plone, result)
+
+    @builtins.property
+    def existing_secret(self) -> typing.Optional[builtins.str]:
+        '''existingSecret - Read admin credentials from user provided secret.
+
+        :default: - undefined
+        '''
+        result = self._values.get("existing_secret")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def limit_cpu(self) -> typing.Optional[builtins.str]:
+        result = self._values.get("limit_cpu")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def limit_memory(self) -> typing.Optional[builtins.str]:
+        result = self._values.get("limit_memory")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def request_cpu(self) -> typing.Optional[builtins.str]:
+        result = self._values.get("request_cpu")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def request_memory(self) -> typing.Optional[builtins.str]:
+        result = self._values.get("request_memory")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def varnish_vcl(self) -> typing.Optional[builtins.str]:
+        '''varnishVcl.
+
+        :default: - file in config folder
+        '''
+        result = self._values.get("varnish_vcl")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def varnish_vcl_file(self) -> typing.Optional[builtins.str]:
+        '''varnishVclFile.
+
+        :default: - undefined
+        '''
+        result = self._values.get("varnish_vcl_file")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "PloneHttpcacheOptions(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.data_type(
     jsii_type="@bluedynamics/cdk8s-plone.PloneOptions",
     jsii_struct_bases=[],
@@ -393,6 +648,7 @@ class PloneBaseOptions:
         "frontend": "frontend",
         "image_pull_secrets": "imagePullSecrets",
         "site_id": "siteId",
+        "variant": "variant",
         "version": "version",
     },
 )
@@ -404,6 +660,7 @@ class PloneOptions:
         frontend: typing.Optional[typing.Union[PloneBaseOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         image_pull_secrets: typing.Optional[typing.Sequence[builtins.str]] = None,
         site_id: typing.Optional[builtins.str] = None,
+        variant: typing.Optional["PloneVariant"] = None,
         version: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -411,6 +668,7 @@ class PloneOptions:
         :param frontend: 
         :param image_pull_secrets: 
         :param site_id: 
+        :param variant: 
         :param version: 
         '''
         if isinstance(backend, dict):
@@ -423,6 +681,7 @@ class PloneOptions:
             check_type(argname="argument frontend", value=frontend, expected_type=type_hints["frontend"])
             check_type(argname="argument image_pull_secrets", value=image_pull_secrets, expected_type=type_hints["image_pull_secrets"])
             check_type(argname="argument site_id", value=site_id, expected_type=type_hints["site_id"])
+            check_type(argname="argument variant", value=variant, expected_type=type_hints["variant"])
             check_type(argname="argument version", value=version, expected_type=type_hints["version"])
         self._values: typing.Dict[builtins.str, typing.Any] = {}
         if backend is not None:
@@ -433,6 +692,8 @@ class PloneOptions:
             self._values["image_pull_secrets"] = image_pull_secrets
         if site_id is not None:
             self._values["site_id"] = site_id
+        if variant is not None:
+            self._values["variant"] = variant
         if version is not None:
             self._values["version"] = version
 
@@ -456,6 +717,11 @@ class PloneOptions:
         result = self._values.get("site_id")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def variant(self) -> typing.Optional["PloneVariant"]:
+        result = self._values.get("variant")
+        return typing.cast(typing.Optional["PloneVariant"], result)
+
     @builtins.property
     def version(self) -> typing.Optional[builtins.str]:
         result = self._values.get("version")
@@ -473,10 +739,19 @@ class PloneOptions:
         )
 
 
+@jsii.enum(jsii_type="@bluedynamics/cdk8s-plone.PloneVariant")
+class PloneVariant(enum.Enum):
+    VOLTO = "VOLTO"
+    CLASSICUI = "CLASSICUI"
+
+
 __all__ = [
     "Plone",
     "PloneBaseOptions",
+    "PloneHttpcache",
+    "PloneHttpcacheOptions",
     "PloneOptions",
+    "PloneVariant",
 ]
 
 publication.publish()
@@ -489,6 +764,7 @@ def _typecheckingstub__543cbcb1139deb4ce75315c33bb5ebd6fd98851d9416a0f8e2c5cd960
     frontend: typing.Optional[typing.Union[PloneBaseOptions, typing.Dict[builtins.str, typing.Any]]] = None,
     image_pull_secrets: typing.Optional[typing.Sequence[builtins.str]] = None,
     site_id: typing.Optional[builtins.str] = None,
+    variant: typing.Optional[PloneVariant] = None,
     version: typing.Optional[builtins.str] = None,
 ) -> None:
     """Type checking stubs"""
@@ -520,12 +796,43 @@ def _typecheckingstub__cd9cf17a63ac3f69f433db3caa859d98a750929386f09ada26dd0fd21
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__f7f85fe682616b18a7851bccc28d7021f541060ebc9eba02965066fd28589e69(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    plone: Plone,
+    existing_secret: typing.Optional[builtins.str] = None,
+    limit_cpu: typing.Optional[builtins.str] = None,
+    limit_memory: typing.Optional[builtins.str] = None,
+    request_cpu: typing.Optional[builtins.str] = None,
+    request_memory: typing.Optional[builtins.str] = None,
+    varnish_vcl: typing.Optional[builtins.str] = None,
+    varnish_vcl_file: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0f974bf721e34d8993ba90020605bc5e09424793236af8b8c5a9bb9a63f1974a(
+    *,
+    plone: Plone,
+    existing_secret: typing.Optional[builtins.str] = None,
+    limit_cpu: typing.Optional[builtins.str] = None,
+    limit_memory: typing.Optional[builtins.str] = None,
+    request_cpu: typing.Optional[builtins.str] = None,
+    request_memory: typing.Optional[builtins.str] = None,
+    varnish_vcl: typing.Optional[builtins.str] = None,
+    varnish_vcl_file: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__d92a415ce6a72ab45cd3d3e169acc7fc8156c275bc6268fa1eed4110e990c22a(
     *,
     backend: typing.Optional[typing.Union[PloneBaseOptions, typing.Dict[builtins.str, typing.Any]]] = None,
     frontend: typing.Optional[typing.Union[PloneBaseOptions, typing.Dict[builtins.str, typing.Any]]] = None,
     image_pull_secrets: typing.Optional[typing.Sequence[builtins.str]] = None,
     site_id: typing.Optional[builtins.str] = None,
+    variant: typing.Optional[PloneVariant] = None,
     version: typing.Optional[builtins.str] = None,
 ) -> None:
     """Type checking stubs"""
